@@ -6,7 +6,7 @@ use swc_common::plugin::Serialized;
 use transform_executor::TransformExecutor;
 
 pub mod cache;
-mod context;
+mod host_environment;
 mod imported_fn;
 mod load_plugin;
 mod memory_interop;
@@ -20,11 +20,17 @@ pub fn apply_transform_plugin(
     program: Serialized,
     config_json: Serialized,
     context_json: Serialized,
+    should_enable_comments_proxy: bool,
 ) -> Result<Serialized, Error> {
     (|| -> Result<_, Error> {
         let mut transform_tracker = TransformExecutor::new(path, cache)?;
-
-        transform_tracker.transform(&program, &config_json, &context_json)
+        let should_enable_comments_proxy = if should_enable_comments_proxy { 1 } else { 0 };
+        transform_tracker.transform(
+            &program,
+            &config_json,
+            &context_json,
+            should_enable_comments_proxy,
+        )
     })()
     .with_context(|| {
         format!(
